/**
 * author: Gabriela Podolnikova
 * inspiration from 365processing.com and The nature of code by Daniel Shiffman
*/

import processing.pdf.*;
import java.util.Calendar;

int num = 500;
float[] x = new float[num];
float[] y = new float[num];

float xspeed = 1;
float yspeed = 3.3;

float diffX;
float diffY;

boolean enableColor = false;
int col;
color c;

boolean enablePoints = false;

void setup() {
  size(2480, 3508);
  smooth();
  frameRate(35);
  background(255);
  beginRecord(PDF, timestamp()+".pdf");
  for (int i = 0; i < num; i++) {
    x[i] = random(width);
    y[i] = random(height);
  }
  colorMode(HSB);
}

void draw() {
  if (enableColor) {
    col += mouseX/(mouseY + 1);
    col %= 255;
    c = color(col, 63, 255);
  }
  for (int i = 0; i < num; i++) {
    x[i] += xspeed;
    if (x[i] > width || x[i] < 0) {
      xspeed = xspeed * -1;
    }
    if (enableColor) {
      stroke(c);
    } else {
      stroke(random(255), 50);
    }
    strokeWeight(random(20));
    ellipse(x[i], y[i], 30+diffX-diffY, 30+diffX-diffY);
  }
  if (enablePoints) {
    for (int i = 0; i < num; i++) {
      y[i] += yspeed;
      if (y[i] > height || y[i] < 0) {
        yspeed = yspeed * -1;
      }
      if (enableColor) {
        fill(c,random(50,100));
      } else {
        fill(random(255), 50);
      }
      point(x[i], y[i]);
    }
  }
  saveFrame("obrazky/retroVibe-####.png");
}

void mouseMoved() {
  diffX = mouseX - pmouseX;
  diffY = mouseY - pmouseY;
  xspeed += (diffX/10);
  xspeed = xspeed % 10;
  yspeed = map(diffY, 0, 500, 0, 3)*100;
}

void keyPressed() {
  if (key=='s' || key=='S') saveFrame(timestamp()+"_##.png");
  if (key == 'q') {
    endRecord();
    exit();
  }
  if (key == 'c') {
    enableColor = true;
  }
  if (key == 'd') {
    enableColor = false;
  }
  if (key == 'f') {
    enablePoints = true;
  }
  if (key == 'l') {
    enablePoints = false;
  }
}

String timestamp() {
  Calendar now = Calendar.getInstance();
  return String.format("%1$ty%1$tm%1$td_%1$tH%1$tM%1$tS", now);
}